/* File:      dataset.h
   Date:      3/20/01  (written fall 2001)
   Author:    C. Paciorek
   Purpose:   header file for dataset.C
*/

class covariate_info;
class sparse_cov_mat_sum;             /* for sum of prior function covariance and data covariance */

extern covariate_info* covariates;

/* this class stores information on the observations and does calculations of likelihood and evaluation criteria */
class dataset {
public:
  dataset(string dat_fn_fn,string fun_form_fn_in, double* noise_sd_in,double* noise_sd_stored_in,double df_parm1_in, double df_parm2_in);
  ~dataset(void);
  void ytoyprime(void);
  void add_info(double* fun_in,double* fun_full_in,double* fun_lnz_R_in,double* fun_lnz_R_stored_in,double* fun_sigma,double* fun_sigma_stored);
  void update(int accepted,int which);      /* update likelihood values */
  double evaluate_loglik_diff(int which);   /* calc log-likelihood diff */

  /******************************
  **** evaluation methods 
  ******************************/

  void initialize_postmean(void);  
  void update_postmean(void);       /* add to running total used for mean calc */
  double* finalize_postmean(void);  /* calculate current postmean values */
  double* calculate_MSE(void);      
  void current_eval(void);          /* MSE and LPD for current iterates */

  double loglik;
  double loglik_stored;
  double* Y;                                /* response */
  double* Yprime;

  double* noise_sd;                         /* error sd; needs to be public because used in gradient for Langevin proposal of f */

  double df, logprior_df;                   /* df stuff for smoothing matrix */
  double current_MSE_train, current_MSE_test;
  sparse_cov_mat_sum* cov;                  /* C_f + C_y */
private:
  double Y2sum;                             /* sum_{i} Y_{i}^2 */

  double* num_trials;                           /* number of Bernoulli trials */

  double* fun;                               /* regr function values on training covariates */
  double* fun_form;                          /* actual function (for simulated functions; or just the observations if the dataset is real */
  double* fun_test;                          /* regr function values on test covariates */
  double* noise_sd_stored;

  /* evaluation stuff */
  double* postmean;
  double* postmean_final;
  int postmean_count;      /* number of iterates used in calculation */

  /* df stuff */
  double df_parm1, df_parm2;
  double logprior_df_stored;
  double df_stored;

};








